@@ -3,11 +3,10 @@
 # SPDX-License-Identifier: MIT
 
 import time
-import busio
 import board
 import adafruit_htu31d
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 htu = adafruit_htu31d.HTU31D(i2c)
 print("Found HTU31D with serial number", hex(htu.serial_number))
 
